package com.sun.tools.javac.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.8-internal-adhoc.pkgsrc.jdk21u-jdk-21.0.8-9-1" },
            { "jdk", "21.0.8" },
            { "release", "21.0.8-internal" },
        };
    }
}
